# RawElements

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**units** | [**list[RawUnit]**](RawUnit.md) |  | [optional] 
**definitions** | [**list[RawDefinition]**](RawDefinition.md) |  | [optional] 
**property_sets** | [**list[RawPropertySet]**](RawPropertySet.md) |  | [optional] 
**classifications** | [**list[RawClassification]**](RawClassification.md) |  | [optional] 
**layers** | [**list[RawLayer]**](RawLayer.md) |  | [optional] 
**systems** | [**list[RawSystem]**](RawSystem.md) |  | [optional] 
**materials** | [**RawMaterialList**](RawMaterialList.md) |  | [optional] 
**elements** | [**list[RawElement]**](RawElement.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


